function OUTIMG=cart_pol(INPIMG)

% Conversion from cartesian to polar coordinate system.

% Nro, Nphi - number of samples over ro-phi coordinates.

% The center of the polar coordinate system is given by X0 and Y0

% coordinates.

[SzX,SzY]=size(INPIMG);

X0=380;

Y0=280;

Nro=SzX;

Nphi=SzY;

corn1=(X0-1)^2+(Y0-1)^2;

corn2=(X0-1)^2+(Y0-SzY)^2;

corn3=(X0-SzX)^2+(Y0-1)^2;

corn4=(X0-SzX)^2+(Y0-SzY)^2;

ro_m=sqrt(max([corn1 corn2 corn3 corn4]));

d_ro=ro_m/Nro;

d_phi=2*pi/Nphi;

ro_phi=0:1:Nro*Nphi-1;

OUTIMG=zeros(Nphi,Nro);

phi=kron(ones(1,Nro),(0:Nphi-1));

ro=kron((0:Nro-1),ones(1,Nphi));

X=round(X0+d_ro*ro.*cos(d_phi*phi)+1);

X=X.*(X>=1)+ones(size(X)).*(X<1);

X=X.*(X<=SzX)+SzX*ones(size(X)).*(X>SzX);

Y=round(Y0+d_ro*ro.*sin(d_phi*phi)+1);

Y=Y.*(Y>=1)+ones(size(Y)).*(Y<1);

Y=Y.*(Y<=SzY)+SzY*ones(size(Y)).*(Y>SzY);

OUTIMG(ro_phi+1)=INPIMG(round(X+SzX*(Y-1)));

OUTIMG=reshape(OUTIMG,Nphi,Nro);

OUTIMG=flipud(OUTIMG');

figure;

imshow(OUTIMG,[]);

colormap(hot);

title('Cartesian to polar mapping');

axis on;

xlabel('\rho');

ylabel('\phi');