function [out_img]=median_filtering(in_img,W1,W2,P)
%	This program demostrates image denoising with median filter.
%   The denoising is performed in sliding window of the size W1xW2.
%        Input arguments:
%        in_img - the input image,
%        W1 - the size of the sliding window in the 
%		 vertical direction (odd integer number),
%        W2 - the size of the sliding window in the 
%		 horizontal direction (odd integer number),
%        P - the probability of salt & pepper noise. 
%        Output arguments:
%        out_img - the output image - the result 
%		 of denoising of the input image in_img contaminated with 
%        salt & pepper noise.

% Add salt & pepper noise.
img_noisy=imnoise(in_img,'salt & pepper',P);

w1=(W1-1)/2;
w2=(W2-1)/2;
[N1,N2]=size(in_img);
% Extend the image in order to cope with boundary effects.
img_noisy_ext=[fliplr(img_noisy(:,1:w2)),img_noisy,fliplr(img_noisy(:,N2-w2+1:N2))];
img_noisy_ext=[flipud(img_noisy_ext(1:w1,:));img_noisy_ext;flipud(img_noisy_ext(N1-w1+1:N1,:))];

% Perform image denoising using median filtering in sliding window.
out_img=zeros(N1,N2);
for i=1:N1
    for j=1:N2
        local_window=img_noisy_ext(i:i+2*w1,j:j+2*w2);
        out_img(i,j)=median(double(local_window(:)));
    end
end

% Display the results.
figure;
subplot(1,3,1);
imshow(in_img,[]);
title('The original image');
subplot(1,3,2);
imshow(img_noisy,[]);
title('The noisy image');
subplot(1,3,3);
imshow(out_img,[]);
title('The image after denoising');